(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     33442,        836]
NotebookOptionsPosition[     31839,        778]
NotebookOutlinePosition[     32265,        794]
CellTagsIndexPosition[     32222,        791]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["The VC package", "Subsection"],

Cell[TextData[{
 "Estimation procedure by Ekkehart Schlicht (University of Munich). \
Implemented by Johannes Ludsteck (Institute for Employment Research \
Nuremberg) for ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " ",
 StyleBox["5.0",
  FontSlant->"Italic"],
 ". adapted to ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " ",
 StyleBox["11,",
  FontSlant->"Italic"],
 " runs also.on ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " ",
 StyleBox["10",
  FontSlant->"Italic"],
 "\n\nVC is a method-of-moments estimation procedure for linear time series \
models with time-varying (random walk) coefficients, developed by Ekkehart \
Schlicht (University of Munich).\n\nConsider the model\n",
 Cell[BoxData[{
  RowBox[{
   SubscriptBox["y", "t"], "=", 
   RowBox[{
    RowBox[{
     SubscriptBox["a", "t"], 
     SubscriptBox["x", "t"]}], "+", 
    SubscriptBox["u", "t"]}]}], "\n", 
  RowBox[{
   RowBox[{
    RowBox[{"where", " ", 
     SubscriptBox["a", "t"], "and", " ", 
     SubscriptBox["x", "t"], "is", " ", "are"}], "-", "vectors"}], ",", 
   RowBox[{
    SubscriptBox["u", "t"], "follows", " ", "a", " ", "normal", " ", 
    "distribution", " ", "and", " ", 
    SubscriptBox["a", "t"], "is", " ", "generated", " ", "by", " ", "a", " ", 
    "random", " ", "walk", " ", "process", " ", "of", " ", "the", " ", 
    "form"}]}], "\n", 
  RowBox[{
   SubscriptBox["a", "t"], "=", 
   RowBox[{
    SubscriptBox["a", 
     RowBox[{"t", "-", "1"}]], "+", 
    SubscriptBox["v", "t"]}]}], "\n", 
  RowBox[{
   RowBox[{
    RowBox[{"where", " ", 
     SubscriptBox["v", "t"], "follows", " ", "a", " ", "multivariate", " ", 
     "normal", " ", "distribution", " ", "with", " ", "mean", " ", "0", " ", 
     "and", " ", "variance"}], "-", 
    RowBox[{"covariance", " ", "matrix", " ", "\[Sum]"}]}], "=", 
   RowBox[{"diag", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubsuperscriptBox["\[Sigma]", "1", "2"], ",", "...", ",", 
       SubsuperscriptBox["\[Sigma]", "n", "2"]}], ")"}], "."}]}]}]}], "Text",
  FontFamily->"Times"],
 "\nIt is routine to estimate such models by Maximum Likelihood using the \
Kalman filter.  However, for short time series, maximum likelihood estimation \
produces corner solutions (",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["\[Sigma]", "i", "2"], TraditionalForm]]],
 "=0) in many cases, even if the true variances are strictly positive. VC \
does better in many cases."
}], "Text",
 CellChangeTimes->{{3.7527248755097656`*^9, 3.7527249651660156`*^9}, {
  3.7531578951621094`*^9, 3.7531579078027344`*^9}, {3.753158174905177*^9, 
  3.753158190474077*^9}},
 FontSize->14],

Cell[CellGroupData[{

Cell["This loads the package", "Subsubsection"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{"NotebookDirectory", "[", "]"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"<<", "VCM11`"}]}], "Input",
 CellChangeTimes->{{3.75290651533631*^9, 3.752906541694605*^9}, {
  3.752906713631711*^9, 3.752906713913506*^9}, {3.7529070858799763`*^9, 
  3.7529070864269657`*^9}}],

Cell["\<\
Two further helper functions. VCModel generates simulated data for a linear \
time series model with varying coefficients.\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"VCModel", "[", 
     RowBox[{"t_", ",", 
      RowBox[{"Sigma_", "?", "MatrixQ"}], ",", 
      RowBox[{"bv_", "?", "VectorQ"}], ",", "uv_", ",", "opts___"}], "]"}], ":=",
     "\[IndentingNewLine]", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"n", "=", 
         RowBox[{"Length", "[", "bv", "]"}]}], ",", "mndist", ",", "brand", 
        ",", "urand", ",", "b", ",", "x", ",", "y", ",", "bMat"}], "}"}], ",",
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"mndist", "=", 
        RowBox[{"MultinormalDistribution", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{"0.0", ",", 
            RowBox[{"{", 
             RowBox[{"n", "-", "1"}], "}"}]}], "]"}], ",", "Sigma"}], "]"}]}],
        ";", "\[IndentingNewLine]", 
       RowBox[{"brand", ":=", 
        RowBox[{"Map", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Random", "[", 
            RowBox[{"NormalDistribution", "[", 
             RowBox[{"0.0", ",", "#"}], "]"}], "]"}], "&"}], ",", 
          RowBox[{"Sqrt", "[", "bv", "]"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"urand", ":=", 
        RowBox[{"RandomVariate", "[", 
         RowBox[{
          RowBox[{"NormalDistribution", "[", 
           RowBox[{"0.0", ",", 
            RowBox[{"Sqrt", "[", "uv", "]"}]}], "]"}], ",", "t"}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"x", "=", 
        RowBox[{"Map", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Join", "[", 
            RowBox[{
             RowBox[{"{", "1.0", "}"}], ",", "#"}], "]"}], "&"}], ",", 
          RowBox[{"RandomVariate", "[", 
           RowBox[{"mndist", ",", "t"}], "]"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"b", "=", 
        RowBox[{"Flatten", "[", 
         RowBox[{"bMat", "=", 
          RowBox[{"NestList", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"#1", "+", "brand"}], "&"}], ",", 
            RowBox[{"Table", "[", 
             RowBox[{"1.0", ",", 
              RowBox[{"{", "n", "}"}]}], "]"}], ",", 
            RowBox[{"t", "-", "1"}]}], "]"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"y", "=", 
        RowBox[{
         RowBox[{
          RowBox[{"X", "[", "x", "]"}], ".", "b"}], "+", "urand"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"y", ",", "x", ",", 
         RowBox[{"Transpose", "[", "bMat", "]"}]}], "}"}]}]}], "]"}]}], ";"}],
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"X", "[", "x_", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"t", ",", "n"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{"t", ",", "n"}], "}"}], "=", 
       RowBox[{"Dimensions", "[", "x", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"SparseArray", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{"i_", ",", "j_"}], "}"}], "/;", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"i", "-", "1"}], ")"}], " ", "n"}], "<", "j", 
           "\[LessEqual]", 
           RowBox[{"i", " ", "n"}]}]}], "\[RuleDelayed]", 
         RowBox[{"x", "\[LeftDoubleBracket]", 
          RowBox[{"i", ",", 
           RowBox[{"j", "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"i", "-", "1"}], ")"}], " ", "n"}]}]}], 
          "\[RightDoubleBracket]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"t", ",", 
          RowBox[{"t", " ", "n"}]}], "}"}]}], "]"}]}]}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.7506561009091797`*^9, 3.7506561198154297`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Here we set the parameters of the model and generate the data\
\>", "Subsubsection"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"SeedRandom", "[", "123", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"t", "=", "50"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"S", "=", 
   RowBox[{"5", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "0.5"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0.5", ",", "1"}], "}"}]}], "}"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"bv", "=", 
   RowBox[{"{", 
    RowBox[{"0.05", ",", "0.1", ",", "0.15"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"y", ",", "x", ",", "b"}], "}"}], "=", 
   RowBox[{"VCModel", "[", 
    RowBox[{"t", ",", "S", ",", "bv", ",", "1.0"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7506720267304688`*^9, 3.7506720371679688`*^9}, {
   3.7507479193222656`*^9, 3.7507479208535156`*^9}, 3.7508618000322266`*^9, {
   3.7527241959541016`*^9, 3.7527242137041016`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["This is a plot of the time paths of the three coefficients", \
"Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"plotseries", "=", 
  RowBox[{"GraphicsGrid", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"ListPlot", "[", 
        RowBox[{"#1", ",", 
         RowBox[{"Joined", "\[Rule]", "True"}], ",", 
         RowBox[{"DisplayFunction", "\[Rule]", "Identity"}], ",", 
         RowBox[{"ImageSize", "\[Rule]", "200"}]}], "]"}], "&"}], ")"}], "/@",
      "b"}], "}"}], "]"}], 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"DisplayFunction", "\[Rule]", "$DisplayFunction"}], ",", 
      RowBox[{"ImageSize", "\[Rule]", "500"}]}], "]"}], "]"}], 
   "*)"}]}]], "Input",
 CellChangeTimes->{{3.7506577606416016`*^9, 3.7506578022978516`*^9}, {
  3.7506579114228516`*^9, 3.7506579194384766`*^9}, {3.7506579938603516`*^9, 
  3.7506580498447266`*^9}, {3.7506580803134766`*^9, 3.7506580886728516`*^9}, {
  3.7509222985791016`*^9, 3.7509223040791016`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{}, {{}, {}, 
        {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
         0.011000000000000001`], AbsoluteThickness[1.6], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAmIQDQEf7FFpBoe2ktdXrWY/hvI5HDJOT/0RyvIQyhdw
WHCkQ1Ne+ziUL+KQqs7eoxJ0BsqXcNh7NiZFufEclC/j4FS7bNstxwdQvoLD
+6Mv3FjVn0H5Sg7ujyeoGES8hPJVHIRem/7PmANzj5rDHpYf2V+DPkH5Gg5r
fwYvueIMk9dyUDV5/eM532soX8dhau0uHhkjmHl6Dm8Yz/fyub+A8g0cNj3Y
z6Nm8gbKN3Tw5mfy/ugBU2/k8GDmZMuMpTC+sUNkeeTECf2foXwTh1V301st
Nb9A+aYO7txdp+TZYPJmDlIFnz1WWMHkzR16zCd6FT7/BuVbODg2urstj4P5
x9LhAtPFzZ3hMPVWDrJPG69ODIeZZ+3wT7jsf5MCTN7GoUnwsGtg+Uco39bh
QF1lzr8omHo7hykLz59ZEALj2zs8iOTdner7Fcp3cGie8EuzfyPU/gYHB8Ud
d6fd6YWZ5+hwZ8Pau9eewOQdHTatiGDZtgEWvk4OKea8yS9LoeobnBwmL4tU
034Aiw9nBw0j/+hufmj4NTg7TDym9iDPEqbfxaF7zparNjuh/AYXB7s9amrC
X2Hyrg5Pbll3SGo/h8q7OqyeFndk4m9YenFzCJo5PWWK122ovJtDzdSUvXv/
XITKuzuEMD/f/IDnBFTe3WEO2+yvLku274fIezisv+rTr2p5ECrv4TBJVims
YvtCqH5Ph8AZ6zLXpS+2BwD4lOeP
          "]]}}, {}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImageSize->200,
      Method->{},
      PlotRange->{{0., 50.}, {-0.09235030170659758, 1.4315045273574212`}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.05], 
         Scaled[0.05]}},
      Ticks->{Automatic, Automatic}], {107.5, -64.89356881873896}, 
     ImageScaled[{0.5, 0.5}], {200, 123.60679774997895`}], InsetBox[
     GraphicsBox[{{}, {{}, {}, 
        {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
         0.011000000000000001`], AbsoluteThickness[1.6], 
         LineBox[CompressedData["
1:eJxV0F1I01EYx/F/s8UiKdOGmm04k5FrmlrL9bL529zUEJcEs1hguIh1Ec5q
mhiZUtZFvlDYm8MMdE28CSnLQlzMKENCjDS1lnQhWjon6cS9YYXP/6IDh4cP
Xw4cHpHRfOwMh2GY9L/331w7C5n/TwZ9gboMQf9vMg/y/Lo4yx03OQKvXUOz
WrOHvA3DRTOhm0q2x4CzumycdkyRd4C5oejsrJwlx6PJt8Fx+dIHcgJ6vuin
paa7jjUnolC39bMhb5y6GL8qDalzumnyLoRfvSCTmRbJEsQ5sTrRz1qK5m6v
9e071inwPy2bb/T7yKnoTpIvpvlXyGnIb5IWDBkZrDkdmtjtc9a8IPW9WDoe
WVIbFiLvw6tAm1cmWibL0Ocb8QxXLJH3w11jK/0kZnsGznEbHNeT2P3KcWWP
7r2wnt3vAZRZKvlFLi/5IAznPaO2qQD5EKqiL0YLtRz632GcnbfYXXbWCpS/
mVGJPrL/V6K38dZPeXIYOROcLsWJkqH1ZODoQvFoyzN6Xw14f2wcNLVyqavQ
Wz7ydWKcXK2CMzFkrnCzXY2Hgm8dD4Q86mqIrqn0+g4ykwX9Ck8yMMD2LLQH
uZrHtZuoa3Byt6xd0RpBXQNp1emYHjuZ0SKl5uWTSf5m6loE1g3GPnpOZrIR
pSz9XtwcTj0bwYb7Y8IXW6jnIGFnV+G925HUcyAQ29pEyWQmF9Kx2kmrM4p6
Lup9/sApNZk5gvgCf4vEyscfHiXc+g==
          "]]}}, {}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImageSize->200,
      Method->{},
      PlotRange->{{0., 50.}, {-0.020901395434939934`, 5.401529758837597}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.05], 
         Scaled[0.05]}},
      Ticks->{Automatic, Automatic}], {322.5, -64.89356881873896}, 
     ImageScaled[{0.5, 0.5}], {200, 123.60679774997895`}], InsetBox[
     GraphicsBox[{{}, {{}, {}, 
        {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
         0.011000000000000001`], AbsoluteThickness[1.6], 
         LineBox[CompressedData["
1:eJxV0mtIU2Ecx/GjLbNiYuCsKLCNmltXc9Nam/qbuzhdIzEwsV6kbhFTEGKR
RskIrUWwikosexWUqDAs7WILVpqtwmytsU1ItLQLTXOQDbSxVfg/Lzrw8PDh
C895zp/Dr64vMyUyDJP9d/3bF59wwf87g3j8W1dO7CM5GW5nRYuiw09OxdLc
y89c54bJaWg60l5eneB1LXoNmO4hMXy3qa9HxFlRO7l/mPoGiLocKcczH1IX
wCDSLZSO+qlvBOdEqDjwYYIshIGzVzHzK0gWITKmv7XK4CNvxnRi4wvevufk
rYhxmrfpy96Tt6M2q9XUf/ItOQtnI85Y46UZ8k5Ujqx80CT4Sc5GSWdUoj09
TZbgcUAcs9hnyVK0R68ZVEOsczCbrtZZkkLkXHy+2uzUzE6SdyFcIk1KCo6R
d0NVfTQ9RTJOloFnbL3BFQbIe3DztyuY4P1KlsPjk6cK/Z/ICsxpHB0NP76Q
81A3YjO6L7I9H17xMbPgPOsCOPzm8cH77DyB8vom/trM8KKtQHLDk3er28iM
Ej2SQ/JR7WvqSnCjE4Ilg+x5hVjXsvzOnGyKeiHyGd7B0CZ2fiqY0voHApXz
1FV4JDVKnVfYrkZneGDHVC/N16pG6b02oSzjO3UN+owvDea6N9Q1WHFdoJzv
Y9+vxUDVK31VL32/VYuabtsBvoW9fxHihzOspzgR6kXwcM/EtlwgMzrkuQNP
1TUL1HVotNs89lH2fyjG3R5v6zL/lOsPI1r9EQ==
          "]]}}, {}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImageSize->200,
      Method->{},
      PlotRange->{{0., 50.}, {-1.64923549012424, 1.}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.05], 
         Scaled[0.05]}},
      Ticks->{Automatic, Automatic}], {537.5, -64.89356881873896}, 
     ImageScaled[{0.5, 0.5}], {200, 123.60679774997895`}]}, {}},
  ContentSelectable->True,
  ImageSize->{657., 141.7871376374779},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{
  3.7506580507666016`*^9, {3.7506580823291016`*^9, 3.7506580895634766`*^9}, 
   3.7506720853085938`*^9, 3.7507479291191406`*^9, 3.750748065908203*^9, 
   3.7508615995947266`*^9, 3.7508618112978516`*^9, 3.7508704811875*^9, 
   3.750870558703125*^9, {3.7509221827666016`*^9, 3.7509222072822266`*^9}, 
   3.7509223055947266`*^9, {3.7527242556572266`*^9, 3.7527242732822266`*^9}, 
   3.7529071324022846`*^9, 3.7531581375273376`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
The next cell contains a call to VCEstimate. VCEstimate returns a List \
containing [1] a matrix with the time paths of the coefficients bhat, [2] a \
matrix with the respective standard errors sdb, [3] the standard error of the \
residual sdu, and [4] the vector of standard errors of the random walk \
residuals sdi. Since the computation of the estimates may be time-consuming \
for lage models, the estimation process is reported\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"bhat", ",", "sdb", ",", "sdu", ",", "sdi"}], "}"}], "=", 
   RowBox[{"VCEstimate", "[", 
    RowBox[{"x", ",", "y"}], "]"}]}], ";"}]], "Input"],

Cell["\<\
Iteration: 69 Objective function value: 240.2201745
Variance Ratios: {0.630826, 0.7393, 0.336136}\
\>", "Output"]
}, Open  ]],

Cell["\<\
The cell above serves as an iteration monitor. It prints the number of \
completed iterations, the actual value of the  convergence criterion and the \
actual value of variance ratios (=sdi/sdu). The convergence criterion used to \
compute the estimator is the maximum of relative changes of the variance \
ratios between two successive steps of the fixed point iteration.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
CIPlot is a helper function which allows to plot the coefficients together \
with confidence interval bands (default option is 0.95 percent bands).\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "CIPlot", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"CILevel", "\[Rule]", "0.95`"}], ",", 
   RowBox[{"RegressorNames", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "200"}], ",", 
   RowBox[{"Columns", "\[Rule]", "2"}]}], "}"}]], "Output",
 CellChangeTimes->{3.7507479484316406`*^9, 3.7508616170634766`*^9, 
  3.752724306892578*^9, 3.752907272839394*^9, 3.7531581572302637`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CIPlot", "[", 
  RowBox[{"bhat", ",", "sdb", ",", 
   RowBox[{"Columns", "\[Rule]", "3"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7509222789072266`*^9, 3.7509222853134766`*^9}, {
  3.752724318564453*^9, 3.752724330033203*^9}, {3.752724411330078*^9, 
  3.752724433001953*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
          0.011000000000000001`], AbsoluteThickness[1.6], 
          LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAmIQDQEf7N/ebN234+xHe6iAw5ZDW0U/FH2C8jkcrrY/
4au58B7KF3BY9kcoaUPSWyhfxEFBR75/WecLKF/CwWLShf28/+5B+TIOK27v
zq7+fQnKV3B45G8+6WD3EShfyYHz3ZSy9yXHoXwVB3ntpiMSAdehfDUHrj8x
F+5cfgjlaziUZ4dqXDd5BeVrOaz7e/WhCd8bKF/HQecvq4VsIMy9eg7mH1mY
BR1h/jFwkHovlFF87juUb+jws0nBt2zNHyjfyCG+quLTW4PfUL6xg9a2l42v
xP9D+SYO16wPHtHf8xfKN3Uw1fuoOU8Mpt7MQa5qavhMPZj55g7PHY+2fj79
Gcq3cAhQ2rLKvwYW3pYOXlOUUhs/wNxr5bBv1zuXXwYw/1g7xN+eWdGkCAtv
G4eMgy0bqvM/QPm2Dt1CSSnSjDD/2TkYm9us2tUEs8/e4UTwMycjmy9QvoPD
oWlxj7ImQ+UbHBzMrXb//nwBpt7RgaXHatney1D1DY4OX64pXDuxA6bfyaHg
15ozH3fB5J0c3BmK/qdMg8k7O2z6sPNubOI3qLyzwxKrp05fl3+Fyrs45P4r
OVnVAPVPg4uD/aPXVR1td6Dyrg6MP82U85dshsq7Oii6Xfh91XDzfoi8m0OJ
B0tn7vZ9EH6Dm8PzpI0K137Ngup3d9jhfFpStG0LVL+7g6pitf33szB5DweW
x8uN3OyboPIeDlfurxc7sOEAVN7TofHIrVpZvXP2APp689c=
           "]]}}, {}}, {{}, {{}, {}, 
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
          0.011000000000000001`], AbsoluteThickness[1.6], 
          Dashing[{0.02, 0.02}], LineBox[CompressedData["
1:eJw10m1IU1Ecx/FbGoqFMzAql7SZDAtNZ5pLs/2cOqeJiRK0TAkfenDBKAsq
qJaR7UWCLyzE1toQY0WQmbsorTbtgcSplZaVaNta21jGRqE5xKzwvwuHy+d8
/y/OgcOvVpbVrWQYJvXf+v9f/vxiS3LhL01oj5k2YOKVCp+Vj4qXGQ5VOds0
fFJPjoK6d1C9rqmb5qOhqRhr1LYOkTfA+vlaWYbcTt4E5/gJ1jzoIvNwJKV/
IxY95Dh4hQ8s3FovOR71o+KrETVOsgBFXEvf7QsT5ARgwBfnjWyk82xDabZV
wA8xUE8E49eqmyXJ5O3QXUxfmHfraD4FFtdh5+mSj2QhXvOnuirfucip2Go7
On/padA7kDbBnpKV/CSn4YVPF6kL95PTkXRwX0fzkpu8EyPTHPuPKzZyBqSK
1t5Z5RhZBM/oen1V+wB5F1rOSG4IMx+SM8Gzr7l/50knnT8LltlYW+BmK3k3
ZBG9rvhHLM1nY8Y4t5l1jJD3QHD2vN4cNk0WozaUFe1dMUEGoo7LX1ZVvFm2
Cji0uFrpM7ylnoMPnOGIc0mT1HOAr/wtjxO+UJfA0Nk2J9hPVkkwe+yu1cNx
UM9FjSK2RRHtpJ6LLKsoJq+IzOSBV+wYl3cbqOfhUxh3qu3eNN0vH2WVzmpP
Cb0HVT4OmHq0k1HfqUvhet43Va8Odin+rEq8PGQKvpcCXDfmLA0FvlEvgE9R
++q90U1dhn5TV+BWYIa6DAtrfxfb2slMITR1ITENDT7zXxUo+5E=
           "]]}}, {}}, {{}, {{}, {}, 
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
          0.011000000000000001`], AbsoluteThickness[1.6], 
          Dashing[{0.02, 0.02}], LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAmIQDQEf7LOVFZbdzWVygAo4rDiwwGhLLQOUz+FgeXXd
orcu/+0hfAEHvRnzdwl2/4PyRRymTK+Mt/rzG8qXcGgy0+lcpP0DypdxcIsQ
mTj30RcoX8FBJyevcMLCj1C+kkN5yO+9nvyfoXwVB9e/D5ZMvPkVyldzuMN0
1s5l83coX8PhUzd/yE6BX1C+lsOMeJ7Xvuf+QPk6DipORT7iQTD36jnYSEvI
F/5lhPrHwMHpUtvpJUdYoHxDh3arlw/ufWeD8o0cQpvivvQ2skL5xg4TvPo8
jn2A8U0cvhwu2Ht/O4xv6rAqXPbgLjEY38whqynw/lxeZijf3KFuy6ZzX2Jh
9ls4BC1ddGBlECx8LR3mNVTcWP8NFp5WDscV7Z2u34P5x9rBLFgq4V7xXyjf
xkGHaZ7Q02KY/2wddJYnMX0Qgpln5xBzQTKntRkmb+9gM/n8bY4YmP0ODgsy
N3P+b4fyGxwcenbd5L02Gybv6MD56kELXx5M3tGhZ9aewk2XYeY7Oex+evOt
zwUov8HJgSvN40wW3H5nh5tTN/10gtnX4OwwlT3cJmUqTN7FgefN2V/Pd0H9
1+DiILZ5T8mqt7D4dnWYJL1Jm8XiPVTe1eHCqgPyaS7PoPJuDqc2VlT333oE
lXdz0JExf1yRA5N3d6hq2+IaKP0aKu/uwCgXY7U16SVU3sPh5m9X7Wndb6Hy
Hg6fGtR1FlR+gsp7OrxLrnjj4PrdHgBnUN27
           "]]}}, {}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      Method->{},
      PlotLabel->FormBox["\"Coeff. 1\"", TraditionalForm],
      PlotRange->{{0., 50.}, {-0.11998638720641158`, 1.9433388781284386`}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.05], 
         Scaled[0.05]}},
      Ticks->{Automatic, Automatic}], {193.5, -116.80842387373012`}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}], InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
          0.011000000000000001`], AbsoluteThickness[1.6], 
          LineBox[CompressedData["
1:eJw10W1IU2EYxvHpFFeWznRRUOlaTBFdzV5cztzlXrUopyNYBSskm0Wk1RcL
smlaYUg1m4EvxPyis4yRoCJIIVqQs6zQXBmmJZq51KFNjLJi9/PA4fA7fzg3
N48wtyAnL5DD4ST9e/6//WdO8efBr5lQ74KCPmBUaeypDvWReeDbNpaXmX6S
+fhsXLgYf26OHIWh8YPyzmjmDbhZtZQ6GuEhb8KXPltlzuNhcgw2u7tlU5JG
8lbcFXJjKmuePfV7G161WUpGJG+pi9G7piajwD1JjkN/1unilVw2Lx7hA5Mi
j2ORnABpb9fxE2eWyRKEf6+KHFr6Td6B/bamgBIL21eKilK10df5jZyEtCxz
7G37PHknKtcJrG4R8y5ccmYHJHqmybshDKl9srg8Qd4D4VSbo+EI+18yPuQX
9TsGmWVQJ9jrV5m95L3Qd60YTB3MKTA8ynP98LB5ctgPvDg5W8fuIxXJruzS
s8lsv324YeS+F2vYfmm4nlh8VZ7Cgd8KzJxvjFP1BZCBNy8v6w+1cP22ABav
y7TQEkQ9HSaFc1DaTLakQ9C8fdw7HExdia/mT8fapSHUlbgiqmjgveNRV0F/
r6L66OvV1FUoqnWuDSoMo67G2MfD+SPpfOpqyKzW8C3iCOoa3HrYOnttmnUN
tLoBcaaQdS1OOdslulbWtYie6A5u0rKug6NcYxjrIFt0KBSInofFRlLPgG3J
4Sp2RVHPwLyzqSywTkA9E6Ie3/0Ld9bjL9Vr4Co=
           "]]}}, {}}, {{}, {{}, {}, 
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
          0.011000000000000001`], AbsoluteThickness[1.6], 
          Dashing[{0.02, 0.02}], LineBox[CompressedData["
1:eJw10HtIU2EYx/GDCUqy2FwOA4dtLbVZqVvltMt+czrXJNFlMVDYmvRHgXRT
qZm5xloXkpb6x8wgaiBUYhTVNDCtqZQw20jKIZF52VJZZhcLCrqw57xwOHzO
9+U9D6/IfER/MIZhGNm/5/87uj4rbz7vlJZxZpT0Abbl8xdcNSFyPAZvn7JM
tSySuWizvxXUH2L3r0bsyGG558cYORk2RUZE+8lPTkGfb/07Q/br/qjXYm9y
Y2m1PkwWI2bmXG6m6wNZAtesdyJpf4Cchlj3HVOT30fnZSDl21KqqMpLlqK0
3JPVv2GCvBFpTx7nhBfmyJthT28WK48vk7Px4hcjSHRMk3PQ82B4MS1yn/4n
g6lcqOL6e6nLEZ+pjKuZfEbeAtQaFa0jN8hboe0euio3sfNtwyXZ0DGHLkDO
hf309daXI+NkBY7eFTSNembJeRiV9bY2t0yS86EbdD7kp7P3uR3u990HElLZ
eXegrmtA2Cj4SN4JV22wY6rnC3kX6pf06TY5ayW6nSE3T/KdDFQ9HdU4Lv6O
2goILHxdxb0/1FXQV3fwIkYG0a6C2rouSeaMiZopQIVxTpQcXkG9AA3clDyz
lO1qDIwFx8+WsV2NxFslqhP8OOqFuDztWAjwV1IvRNamtvB01irqRRDXBb+e
9CVQL8K+ayULnRwOdQ1Mw5VrLPNs16Brj0Y98YrMFGPW294gMNF+azGEZogr
z3Cpa2FVGzIeveFR18IQutInmSczu5Hf/lPYE+LhL/Yx2aI=
           "]]}}, {}}, {{}, {{}, {}, 
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
          0.011000000000000001`], AbsoluteThickness[1.6], 
          Dashing[{0.02, 0.02}], LineBox[CompressedData["
1:eJw1z3lIE2AYx/FtKS7LytSlWZgWrZqFLlvq2vbzmCerKdihkWxoLKG2aBl5
FxoUEYWNMiVQMZ1ZBjY1AmNWlFFY2uHCJAVTipp5rOXsxOd94eXl837fP94n
WKtPz+VxOBzxv/3/nF8Tipah+kf6D38UdAG5UlIXZuBinnzIMxzPr0zNUV+G
fHvRYFWjg+wLkY/VfIbrIvtDV3Gbq3rrJK+CZp9viWLtd/IanDhmykDkZ3II
jDf4u3pMfeR1uGbW6sdsrK9HTmf5/uygafIGCDSvBwoyf5M3YXR0QmaJ59F/
Q9EkUFcetC8gb4Fqj+p0+wPWw3CnRe10yti84Wj/iic9tlmyGG05BxqW9HPo
/VYMBtVa+9yZI9AkNtzlHWHvt2Fvmhb2nZNkCUqqlV5cjxnydtxLvqT7UTdF
jsRLXodLNPmTHIWo4ZCh48Jf5GhcFjbe9O9j80nRWZl1PvQN+/8OrKwdjn4R
7kaWQXpdcNYyzuaVI20k/Ysl04OswKnqrNJit4VkwCi5UGzzI5cBM8KLV+Xl
rMcgL/BxVf40n3oMxvqlrW3BrMfCaHhl2l3kST0WpRLnotbCpdTjMGFe3Rwg
9KYeB/0zz8Mpn5ZTj8eccvx970kf6vEY8MoSpUSQOUpU1BTkpn5jXQmNdfZd
133WE1BTbFWnHWU9Abr6kUPaBl/qicje2KXrsJLLEvHwqXted68f9SQ033IZ
krpXUE/CuUJr6kdVAPVkLLY7vDdHB+IvmcHYsg==
           "]]}}, {}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      Method->{},
      PlotLabel->FormBox["\"Coeff. 2\"", TraditionalForm],
      PlotRange->{{0., 50.}, {-0.12971653044793333`, 5.64106213998551}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.05], 
         Scaled[0.05]}},
      Ticks->{Automatic, Automatic}], {580.5, -116.80842387373012`}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}], InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
          0.011000000000000001`], AbsoluteThickness[1.6], 
          LineBox[CompressedData["
1:eJw1z31IU1EYx/GLSkVhrZuQYYFz2dzsxZbm1Gw/p06HWlZgkLrSjEhay15U
YpKUSDUK7C/BSpRCYkEiKyScC1diqbSkcsvl2rQpI8mpNRGzF3zOhcvlc77P
vedcYanu8KkgjuNk/+7/z+VrWiHZaEqw4rKFFrBubcfEpvcNimWuQojhzfca
PbMA0Tts3S5lM82HIbbV8OmcoZscDqvCXV+hMZI3o79q8ZBBbyNHonDF4/HW
+WFyFKxmvjnvoYO8Fa6y3vV3+RHyNgwLw569mP1MjoFEr/hWrWaW4sGFm9Ih
B5vfDv7A0omFYDt5JzacGTt4rY85DuKmrtdFsR7ybpwUxVQJ2rxkGbQfO0sk
oUPkPdBWDT5528POG4937T0l014nOQFJxZwufGyUvBd8hLHO6nSRE/HUb4zu
m/1KlsMWcvGI/Q5zEq7kmnsmy9l5kjEhtr3SOMbJKdjyITKovNFN3geNTzlQ
cJbNp0IQdXr8uJZ5P/oe2b8k6pgVGEzJ3SXPYwYsIunReh/9by1w61LEgsDk
o56G/IZf15Mrf1BPw3lR8e2U/BnqSogH/sStGZ2jrkTky3a391iAejq6au83
ThjmqacjJ/xGtYyneS4D6qk6T1OOn3oGhIupK0dEbP9MBMo8vqWWMeqZCA32
8yEdk9RV6Fzqd9bMTVFXYabA+1s8Q9/jshBvNi26VT+pZ6Et8NyzWk/msmEu
kpfGXGU9Gx29GQLuHntfDUdhReWkzmf5C0v1B3U=
           "]]}}, {}}, {{}, {{}, {}, 
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
          0.011000000000000001`], AbsoluteThickness[1.6], 
          Dashing[{0.02, 0.02}], LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAmIQDQEf7M+8tb1//v6n/VABB/Hw38n/gz9A+RwOx4/n
ikRWvobyBRxSjra9Mlj8HMoXcXjVUd9cZvcEypdwWP16ZWLo1odQvozDt3ur
1NxXvYLyFRzUWf4n82vDzFdyWLa6JnvPJRhfxYHhg8H+kifvoHw1h1enYvc/
3gST13Cw8CqYcqH7PZSv5RCt/ZU/xuoFlK/jsOd1ouM6V5h9eg4mYcwfDNth
+g0c/nil+jb8/gzlGzpsyl7TVyb6Fco3cnA63VLTHgHTb+yQwCHaZ1v7Eco3
ceiatCOL/SJMv6lDgP46PcaPMP1mDpWHey9+3vsNyjd3kOvnfiLb/x3Kt3Bg
+DvL+NBvmLylg4ioaT0vF0zeyqFs8Y7nMqkweWuHplerz775BosfGwe2AJvC
+Ksw99g6dNQ8mrFVDuYeO4c+o31rdmfD1Ns78N08NtsoGhaeDg5PnNm/2679
AuE3ODio7V8tPnknzH5HBw0b1h9mKb+h8o4Oejk3z1zz/geVd3LIm33vHuP7
/1B5J4espbOmyP+E8hmcHXavfPxHQwSqvsHZYVc/V2H/NKh5DC4ORVozpqds
gvqvwcXh5RzZCfbqsPBzdfij7ap2OxEaXw2uDq9WbXttogYLDzcHsxx5w5YF
P6Hybg4J/Udi2m/BzHd36HwSt2YG11+ovLvDkjXH/2w+D+UzeDgwH3rz11Ua
5j8Ph3XRgd/KKn9A5T0dpjFZsc3++XU/ABRuDHY=
           "]]}}, {}}, {{}, {{}, {}, 
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
          0.011000000000000001`], AbsoluteThickness[1.6], 
          Dashing[{0.02, 0.02}], LineBox[CompressedData["
1:eJw1z2tIk1Ecx/E5Qw1JRsswGmEiUiZWm2vT5vabl7lSUmQ5K5NVGJHJelOi
aShhk0RkBoVKE3wxmUYXw9hybjNTZ1BOZ8Vq2VKWl+UlhUTKqNh/DxwOn/M9
53CevefV+SVMBoPB/Tf+z/5vRaKrmyg80bsqoQVoZoW8+ukVchjKVSlr0drv
ZBaaX7YsMR97yTtghamNL3CRo1CiaTsXcddN5kD5tshQfmaSHA1vcNfw+gsH
OQZs3ht1ATPgWGw5pSiNbLKQ4/Bz7EEczz5K3gexcNBcvHWIHI+olI7JJ7/M
Vr8TkLPICW7f1kM9EYbbsujBhsD9h1C4eadSyOwnH0bYjT6NbpeJznNh8N3n
m+8F9vPQyTVNqdTvyUlomCuaFV1/R+ZjjGl0OzcD/38Etg8ekVz8iSyA5drN
jYKyj2QhbJ72ms5ngf3JuBTz5Udz1QQ5BStGTeJ0n5F8FHkXnxoT5nrJIrCy
nSrfVAe9NxWs3NKm5/F66mIwHC3O+q/Z1CVIrJSFr/+2kwH3n51B6QsDftcA
nO5q9rJzhLoUOsXQwQi5g7oU9su3BLX5LuppGNiQhuxvnaGehoe9jWeLKhap
p6NfqUzSB69RT4dJGs7o3j1PPQNS1cxp/egs9Qx4qmrdZatO6plwj8zH7gl6
TT0TnIGJ5IriV9RlCDve8+hb7jh1GUJTWWIt20M9C5YDka0FIT7qWThZl6Md
zFugLsfSUmhj5PAydTmuXLiq2F7tpX4MESWfbXzXuPUvrJbybg==
           "]]}}, {}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      Method->{},
      PlotLabel->FormBox["\"Coeff. 3\"", TraditionalForm],
      PlotRange->{{0., 50.}, {-1.5341564141781836`, 0.017399220244000143`}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.05], 
         Scaled[0.05]}},
      Ticks->{Automatic, Automatic}], {967.5, -116.80842387373012`}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}]}, {}},
  ContentSelectable->True,
  ImageSize->600,
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{3.752724499564453*^9, 3.752907285209157*^9, 
  3.7531581607090864`*^9}]
}, Open  ]],

Cell["\<\
The extension of VC to panel data is straightforward. This extension is \
implemented in the package. Since only less users will be interested in panel \
data applications, we do not demonstrate them here. The interested reader is \
referred to the package documentation (type ?VCEstimate). Note that panel \
data are tractable only if the cross-section dimension and time dimension are \
small (less than 100).\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
References
\
\>", "Subsubsection",
 CellChangeTimes->{{3.752725290977539*^9, 3.752725299368164*^9}, {
  3.7527253731601562`*^9, 3.7527253790820312`*^9}}],

Cell["\<\
Ludsteck, Johannes (2004), \[OpenCurlyDoubleQuote]VC - An estimator for \
linear (time series and panel) models with time-varying coefficients\
\[CloseCurlyDoubleQuote], \
http://library.wolfram.com/infocenter/MathSource/5195/

Schlicht, Ekkehart (1989), \[CloseCurlyDoubleQuote]Variance Estimation in a \
Random Coefficients Model\[CloseCurlyDoubleQuote], paper presented at the \
Econometric Society European Meeting 1989 in Munich, Germany, \
https://epub.ub.uni-muenchen.de/59143/

Schlicht, Ekkehart and Ludsteck, Johannes (2006), \
\[CloseCurlyDoubleQuote]Variance Estimation in a Random Coefficients Model\
\[CloseCurlyDoubleQuote], Discussion Papers in Economics 904, University of \
Munich, Department of Economics. \
https://ideas.repec.org/p/lmu/muenec/904.html \
\>", "Text",
 CellChangeTimes->{{3.7527253966601562`*^9, 3.7527254975478516`*^9}, {
   3.7527255862978516`*^9, 3.7527256533759766`*^9}, {3.7527257084960938`*^9, 
   3.7527257335585938`*^9}, {3.752725811279297*^9, 3.752725839810547*^9}, {
   3.752725874107422*^9, 3.752725880529297*^9}, 3.7527261623623047`*^9}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{721, 659},
WindowMargins->{{49, Automatic}, {-106, Automatic}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
FrontEndVersion->"10.3 for Microsoft Windows (64-bit) (December 10, 2015)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 36, 0, 49, "Subsection"],
Cell[618, 24, 2638, 75, 346, "Text"],
Cell[CellGroupData[{
Cell[3281, 103, 47, 0, 39, "Subsubsection"],
Cell[3331, 105, 346, 8, 52, "Input"],
Cell[3680, 115, 146, 3, 49, "Text"],
Cell[3829, 120, 3877, 108, 292, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7743, 233, 94, 2, 39, "Subsubsection"],
Cell[7840, 237, 960, 28, 112, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8837, 270, 85, 1, 39, "Subsubsection"],
Cell[CellGroupData[{
Cell[8947, 275, 921, 23, 112, "Input"],
Cell[9871, 300, 6038, 131, 157, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[15958, 437, 466, 7, 179, "Subsubsection"],
Cell[CellGroupData[{
Cell[16449, 448, 208, 6, 31, "Input"],
Cell[16660, 456, 123, 3, 48, "Output"]
}, Open  ]],
Cell[16798, 462, 396, 6, 87, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[17231, 473, 180, 3, 67, "Subsubsection"],
Cell[CellGroupData[{
Cell[17436, 480, 65, 1, 31, "Input"],
Cell[17504, 483, 399, 8, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[17940, 496, 301, 6, 31, "Input"],
Cell[18244, 504, 11819, 228, 178, "Output"]
}, Open  ]],
Cell[30078, 735, 435, 7, 106, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[30550, 747, 163, 5, 67, "Subsubsection"],
Cell[30716, 754, 1095, 20, 201, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)

